@@ -34,6 +34,9 @@
 #include "metaevent.h"
 
 #define AUDIO_METER_INTERVAL 50
+#define PLL_SETTLE_INTERVAL 100
+#define PLL_CORRECTION 0.00001
+#define PLL_CORRECTION_LIMIT 0.001
 
 class AudioDevice : public QObject
 {
