@@ -33,7 +33,10 @@ class CodecNull : public Codec
   bool acceptsContentType(const QString &str) const;
   QString defaultExtension() const;
   bool acceptsFormatIdentifier(const QString &str) const;
-  void process(const QByteArray &data);
+  void process(const QByteArray &data,bool is_last);
+
+ protected:
+  void loadStats(QStringList *hdrs,QStringList *values,bool is_first);
 };
 
 
