@@ -18,16 +18,27 @@
 //   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 //
 
+#include "conn_file.h"
+#include "conn_hls.h"
 #include "conn_xcast.h"
 #include "connectorfactory.h"
 
-Connector *ConnectorFactory(Connector::ServerType type,QObject *parent)
+Connector *ConnectorFactory(Connector::ServerType type,const QString &mimetype,
+			    QObject *parent)
 {
   Connector *conn=NULL;
 
   switch(type) {
+  case Connector::HlsServer:
+    conn=new Hls(mimetype,parent);
+    break;
+
   case Connector::XCastServer:
-    conn=new XCast(parent);
+    conn=new XCast(mimetype,parent);
+    break;
+
+  case Connector::FileServer:
+    conn=new File(mimetype,parent);
     break;
 
   case Connector::LastServer:
