@@ -23,10 +23,6 @@
 #include "dev_alsa.h"
 #include "logging.h"
 
-#define PLL_SETTLE_INTERVAL 100
-#define PLL_CORRECTION 0.00001
-#define PLL_CORRECTION_LIMIT 0.001
-
 void *AlsaCallback(void *ptr)
 {
 #ifdef ALSA
@@ -44,6 +40,8 @@ void *AlsaCallback(void *ptr)
   static unsigned count=0;
   static bool show_xrun=false;
   static double pll_setpoint_ratio;
+  static float lvls[MAX_AUDIO_CHANNELS];
+  static unsigned i;
 
   dev=(DevAlsa *)ptr;
   src=NULL;
@@ -154,6 +152,11 @@ void *AlsaCallback(void *ptr)
       case AudioDevice::LastFormat:
 	break;
       }
+      dev->peakLevels(lvls,pcm_s3,n,dev->codec()->channels());
+      for(i=0;i<dev->codec()->channels();i++) {
+	dev->alsa_meter_avg[i]->addValue(lvls[i]);
+      }
+      dev->setMeterLevels(lvls);
     }
   }
 
@@ -183,6 +186,12 @@ DevAlsa::DevAlsa(Codec *codec,QObject *parent)
   alsa_pcm_buffer=NULL;
   alsa_stopping=false;
 
+  for(int i=0;i<MAX_AUDIO_CHANNELS;i++) {
+    alsa_meter_avg[i]=new MeterAverage(8);
+  }
+  alsa_meter_timer=new QTimer(this);
+  connect(alsa_meter_timer,SIGNAL(timeout()),this,SLOT(meterData()));
+
   alsa_play_position_timer=new QTimer(this);
   connect(alsa_play_position_timer,SIGNAL(timeout()),
 	  this,SLOT(playPositionData()));
@@ -193,10 +202,15 @@ DevAlsa::DevAlsa(Codec *codec,QObject *parent)
 DevAlsa::~DevAlsa()
 {
   stop();
+  for(int i=0;i<MAX_AUDIO_CHANNELS;i++) {
+    delete alsa_meter_avg[i];
+  }
+  delete alsa_meter_timer;
   if(alsa_pcm_buffer!=NULL) {
     delete alsa_pcm_buffer;
   }
   delete alsa_play_position_timer;
+
 }
 
 
@@ -354,6 +368,7 @@ bool DevAlsa::start(QString *err)
   //  alsa_meter_timer->start(AUDIO_METER_INTERVAL);
 
   alsa_play_position_timer->start(50);
+  alsa_meter_timer->start(AUDIO_METER_INTERVAL);
 
   return true;
 #else
@@ -375,6 +390,17 @@ void DevAlsa::playPositionData()
 }
 
 
+void DevAlsa::meterData()
+{
+  float lvls[MAX_AUDIO_CHANNELS];
+
+  for(unsigned i=0;i<codec()->channels();i++) {
+    lvls[i]=alsa_meter_avg[i]->average();
+  }
+  setMeterLevels(lvls);
+}
+
+
 void DevAlsa::loadStats(QStringList *hdrs,QStringList *values,bool is_first)
 {
   if(is_first) {
@@ -387,19 +413,19 @@ void DevAlsa::loadStats(QStringList *hdrs,QStringList *values,bool is_first)
     hdrs->push_back("Device|Channels");
     values->push_back(QString().sprintf("%u",alsa_channels));
 
-    hdrs->push_back("Device|SampleRate");
+    hdrs->push_back("Device|Samplerate");
     values->push_back(QString().sprintf("%u",alsa_samplerate));
 
-    hdrs->push_back("Device|BufferSize");
+    hdrs->push_back("Device|Buffer Size");
     values->push_back(QString().sprintf("%lu",alsa_buffer_size));
 
-    hdrs->push_back("Device|PeriodQuantity");
+    hdrs->push_back("Device|Period Quantity");
     values->push_back(QString().sprintf("%u",alsa_period_quantity));
   }
 
-  hdrs->push_back("Device|PllOffset");
+  hdrs->push_back("Device|PLL Offset");
   values->push_back(QString().sprintf("%8.6lf",alsa_pll_offset));
 
-  hdrs->push_back("Device|PllSetpointFrames");
+  hdrs->push_back("Device|PLL Setpoint Frames");
   values->push_back(QString().sprintf("%u",alsa_pll_setpoint_frames));
 }
