@@ -37,7 +37,10 @@ class DevFile : public AudioDevice
   void stop();
 
  public slots:
-   void synchronousWrite(unsigned frames);
+   void synchronousWrite(unsigned frames,bool is_last);
+
+ protected:
+   void loadStats(QStringList *hdrs,QStringList *values,bool is_first);
 
  private:
   AudioDevice::Format file_format;
