@@ -53,6 +53,7 @@ MainObject::MainObject(QObject *parent)
   sir_codec=NULL;
   sir_ring=NULL;
   sir_audio_device=NULL;
+  sir_meter_data=false;
   sir_server_id=NULL;
   sir_first_stats=true;
   disable_stream_metadata=false;
@@ -100,6 +101,18 @@ MainObject::MainObject(QObject *parent)
       list_devices=true;
       cmd->setProcessed(i,true);
     }
+    if(cmd->key(i)=="--meter-data") {
+      sir_meter_data=true;
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--server-script-down") {
+      sir_server_script_down=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
+    if(cmd->key(i)=="--server-script-up") {
+      sir_server_script_up=cmd->value(i);
+      cmd->setProcessed(i,true);
+    }
     if(cmd->key(i)=="--stats-out") {
       sir_stats_out=true;
       cmd->setProcessed(i,true);
@@ -237,9 +250,13 @@ void MainObject::serverConnectedData(bool state)
     connect(sir_codec,SIGNAL(framed(unsigned,unsigned,unsigned,Ringbuffer *)),
 	    this,
 	    SLOT(codecFramedData(unsigned,unsigned,unsigned,Ringbuffer *)));
+    if(!sir_server_script_up.isEmpty()) {
+      RunScript(sir_server_script_up);
+    }
   }
   else {
     sir_starvation_timer->stop();
+    sir_meter_timer->stop();
     if(sir_audio_device!=NULL) {
       delete sir_audio_device;
       sir_audio_device=NULL;
@@ -248,6 +265,9 @@ void MainObject::serverConnectedData(bool state)
       delete sir_codec;
       sir_codec=NULL;
     }
+    if(!sir_server_script_down.isEmpty()) {
+      RunScript(sir_server_script_down);
+    }
   }
 }
 
@@ -290,6 +310,11 @@ void MainObject::codecFramedData(unsigned chans,unsigned samprate,
   if(sir_stats_out) {
     sir_stats_timer->start(2000);
   }
+  sir_meter_timer=new QTimer(this);
+  connect(sir_meter_timer,SIGNAL(timeout()),this,SLOT(meterData()));
+  if(sir_meter_data) {
+    sir_meter_timer->start(AUDIO_METER_INTERVAL);
+  }
   sir_starvation_timer->start(1000);
 }
 
@@ -365,9 +390,32 @@ void MainObject::statsData()
 }
 
 
+void MainObject::meterData()
+{
+  int lvls[MAX_AUDIO_CHANNELS];
+
+  sir_audio_device->meterLevels(lvls);
+  switch(sir_codec->channels()) {
+  case 1:
+    printf("ME %04X%04X\n",0xFFFF&lvls[0],0xFFFF&lvls[0]);
+    break;
+
+  case 2:
+    printf("ME %04X%04X\n",0xFFFF&lvls[0],0xFFFF&lvls[1]);
+    break;
+  }
+  fflush(stdout);
+}
+
+
 void MainObject::exitData()
 {
   if(global_exiting) {
+    if((sir_connector!=NULL)&&(!sir_server_script_down.isEmpty())) {
+      if(sir_connector->isConnected()) {
+	RunScript(sir_server_script_down);
+      }
+    }
     if(sir_audio_device!=NULL) {
       sir_audio_device->stop();
       delete sir_audio_device;
@@ -412,6 +460,22 @@ void MainObject::ListDevices()
 }
 
 
+void MainObject::RunScript(const QString &cmd)
+{
+  QStringList args;
+  QString prog;
+  QProcess *proc;
+
+  args=cmd.split(" ");
+  prog=args[0];
+  args.erase(args.begin());
+  proc=new QProcess(this);
+  proc->start(prog,args);
+  proc->waitForFinished();
+  delete proc;
+}
+
+
 int main(int argc,char *argv[])
 {
   QCoreApplication a(argc,argv);
