@@ -23,6 +23,7 @@
 #define GLASSPLAYER_H
 
 #include <QObject>
+#include <QProcess>
 #include <QTimer>
 #include <QUrl>
 
@@ -49,17 +50,21 @@ class MainObject : public QObject
   void metadataReceivedData(MetaEvent *e);
   void starvationData();
   void statsData();
+  void meterData();
   void exitData();
 
  private:
   void ListCodecs();
   void ListDevices();
+  void RunScript(const QString &cmd);
   Connector::ServerType server_type;
   AudioDevice::Type audio_device_type;
   QUrl server_url;
   bool disable_stream_metadata;
   bool dump_bitstream;
   bool sir_stats_out;
+  QString sir_server_script_up;
+  QString sir_server_script_down;
   QStringList device_keys;
   QStringList device_values;
   bool list_codecs;
@@ -73,6 +78,8 @@ class MainObject : public QObject
   QTimer *sir_stats_timer;
   MetaEvent sir_meta_event;
   bool sir_first_stats;
+  bool sir_meter_data;
+  QTimer *sir_meter_timer;
 };
 
 
